habitat.utils.immortal_changes
==============================

.. automodule:: habitat.utils.immortal_changes

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Consumer
   
   

   
   
   